##
##  milter-dkim.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2009 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         milter-dkim
Summary:      Mail Filter for DomainKeys Identified Mail (DKIM)
URL:          http://dk-milter.sourceforge.net/
Vendor:       Sendmail, Inc.
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        EVAL
Group:        Mail
License:      Open Source
Version:      2.8.3
Release:      20090826

#   package options
%option       with_fsl  yes

#   list of sources
Source0:      http://switch.dl.sourceforge.net/dkim-milter/dkim-milter-%{version}.tar.gz
Source1:      rc.milter-dkim
Source2:      fsl.milter-dkim
Source3:      milter-dkim-genkey.sh
Patch0:       milter-dkim.patch

#   build information
Prefix:       %{l_prefix}
BuildRoot:    %{l_buildroot}
BuildPreReq:  OpenPKG, openpkg >= 20060823
PreReq:       OpenPKG, openpkg >= 20060823
BuildPreReq:  milter, openssl
PreReq:       milter, openssl
%if "%{with_fsl}" == "yes"
BuildPreReq:  fsl
PreReq:       fsl
%endif
AutoReq:      no
AutoReqProv:  no

%description
    This is a DomainKeys Identified Mail (DKIM) based mail sender
    authentication based on the MILTER API of MTAs. DKIM is the a merger
    and enhancement of Yahoo! DomainKeys and Cisco Identified Internet
    Mail (IIM). DKIM is upward compatible with existing DomainKeys DNS
    records.

%track
    prog milter-dkim = {
        version   = %{version}
        url       = http://sourceforge.net/projects/dkim-milter/files/
        regex     = dkim-milter-(\d+(\.\d+)+)\.tar\.gz
    }

%prep
    %setup -q -n dkim-milter-%{version}
    %patch -p0

%build
    #   configure program
    extlibs="-lcrypto %{l_fsl_libs}"
    case "%{l_platform -t}" in
        *-sunos* ) extlibs="$extlibs -lrt" ;;
    esac
    (   echo "define(\`confCC', \`%{l_cc} %{l_cflags}')dnl"
        echo "APPENDDEF(\`confINCDIRS', \`%{l_cppflags}')dnl"
        echo "APPENDDEF(\`confLIBDIRS', \`%{l_ldflags} %{l_fsl_ldflags}')dnl"
        echo "APPENDDEF(\`confLIBS', \`$extlibs')dnl"
    ) >devtools/Site/site.config.m4

    #   build program
    ./Build

%install
    #   create installation hierarchy
    rm -rf $RPM_BUILD_ROOT
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/fsl \
        $RPM_BUILD_ROOT%{l_prefix}/etc/milter-dkim \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/man/man8 \
        $RPM_BUILD_ROOT%{l_prefix}/var/milter-dkim/milter-dkim.tmp

    #   install program
    %{l_shtool} install -c -s -m 755 \
        obj.*/dkim-filter/dkim-filter $RPM_BUILD_ROOT%{l_prefix}/sbin/
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE milter-dkim-genkey.sh} $RPM_BUILD_ROOT%{l_prefix}/sbin/milter-dkim-genkey

    #   install manual page
    %{l_shtool} install -c -m 644 \
        dkim-filter/dkim-filter.8 $RPM_BUILD_ROOT%{l_prefix}/man/man8/

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.milter-dkim} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install OSSP fsl configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE fsl.milter-dkim} $RPM_BUILD_ROOT%{l_prefix}/etc/fsl/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/fsl/*' \
        '%attr(755,%{l_rusr},%{l_mgrp}) %{l_prefix}/var/milter-dkim/*' \
        '%attr(755,%{l_rusr},%{l_mgrp}) %{l_prefix}/var/milter-dkim'

%files -f files

%clean
    rm -rf $RPM_BUILD_ROOT

%post
    #   after upgrade, restart service
    if [ $1 -eq 1 ]; then
        if [ ! -f $RPM_INSTALL_PREFIX/etc/milter-dkim/mail.example.com.pem ]; then
            $RPM_INSTALL_PREFIX/sbin/milter-dkim-genkey \
                mail example.com $RPM_INSTALL_PREFIX/etc/milter-dkim/mail.example.com.pem 1024
        fi
    elif [ $1 -eq 2 ]; then
        eval `%{l_rc} milter-dkim status 2>/dev/null`
        [ ".$milter_dkim_active" = .yes ] && %{l_rc} milter-dkim restart
    fi
    exit 0

%preun
    #   before erase, stop service and remove log files
    if [ $1 -eq 0 ]; then
        %{l_rc} milter-dkim stop 2>/dev/null
        rm -f $RPM_INSTALL_PREFIX/etc/milter-dkim/mail.example.com.pem >/dev/null 2>&1 || true
        rm -f $RPM_INSTALL_PREFIX/var/milter-dkim/milter-dkim.log      >/dev/null 2>&1 || true
        rm -f $RPM_INSTALL_PREFIX/var/milter-dkim/milter-dkim.pid      >/dev/null 2>&1 || true
        rm -f $RPM_INSTALL_PREFIX/var/milter-dkim/milter-dkim.tmp/*    >/dev/null 2>&1 || true
    fi
    exit 0

